Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(11)

Unified Diff: components/sync/protocol/user_event_specifics.proto

Issue 2897563002: Implement client side logging for language detection. (Closed)
Patch Set: update comment Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « components/sync/protocol/proto_visitors.h ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: components/sync/protocol/user_event_specifics.proto
diff --git a/components/sync/protocol/user_event_specifics.proto b/components/sync/protocol/user_event_specifics.proto
index d02b2833eb7ca9db5b8859bb587a5b799e961b5b..d36d7642c80aa0d8678d95212ac2409f46c3ad59 100644
--- a/components/sync/protocol/user_event_specifics.proto
+++ b/components/sync/protocol/user_event_specifics.proto
@@ -34,9 +34,9 @@ message LanguageDetection {
// we're not confident about, we may log up to 3 top languages in descending
// order.
repeated Language detected_languages = 1;
// Adopted language is the final determined language.
// It will be stored only if it's different from the first detected language.
- optional string adopted_language = 2;
+ optional string adopted_language_code = 2;
}
message UserEventSpecifics {
« no previous file with comments | « components/sync/protocol/proto_visitors.h ('k') | no next file » | no next file with comments »
@@ -34,9 +34,9 @@ message LanguageDetection {
// order.
repeated Language detected_languages = 1;
- // Adopted language is the final determined language.
+ // Adopted language code is the code of final determined language.
// It will be stored only if it's different from the first detected language.

Powered by Google App Engine
This is Rietveld 408576698